@@ -1,4 +1,4 @@
-# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015-2016 Hewlett Packard Enterprise Development Company LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -60,12 +60,14 @@ class RetryEngine(object):
             ntype = notification_data['type']
             name = notification_data['name']
             addr = notification_data['address']
+            period = notification_data['period']
 
             notification = Notification(ntype,
                                         partition,
                                         offset,
                                         name,
                                         addr,
+                                        period,
                                         notification_data['retry_count'],
                                         notification_data['raw_alarm'])
 
@@ -78,7 +80,8 @@ class RetryEngine(object):
             sent, failed = self._notifier.send([notification])
 
             if sent:
-                self._producer.publish(self._topics['notification_topic'], sent)
+                self._producer.publish(self._topics['notification_topic'],
+                                       [notification.to_json()])
 
             if failed:
                 notification.retry_count += 1
